# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ContentBlockTypeStrEnum(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    TEXT = 'text'
    HTML = 'html'
    BTN = 'btn'
    VIDEO = 'video'
    AUDIO = 'audio'
    PDF = 'pdf'
    QUIZ_TEXT = 'quiz_text'
    QUIZ_VIDEO = 'quiz_video'
    QUIZ_AUDIO = 'quiz_audio'
    CERTIFICATE = 'certificate'

    @classmethod
    def from_json(cls, json_str: str) -> ContentBlockTypeStrEnum:
        """Create an instance of ContentBlockTypeStrEnum from a JSON string"""
        return ContentBlockTypeStrEnum(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from public_api_server_connector.models.attached_file_create import AttachedFileCreate
from public_api_server_connector.models.content_block_create import ContentBlockCreate
from public_api_server_connector.models.lesson_type_str_enum import LessonTypeStrEnum

class ModuleLessonCreate(BaseModel):
    """
    ModuleLessonCreate
    """
    submodule_id: Optional[StrictInt] = Field(default=None, description="ID of the submodule this lesson belongs to, if not part of submodule, it is null, defaults to null")
    thread_id: Optional[StrictInt] = Field(default=None, description="ID of the community thread this lesson belongs to, if not part of thread, it is null, defaults to null")
    lesson_type: LessonTypeStrEnum = Field(default=..., description="Type of the lesson")
    image_id: Optional[StrictStr] = Field(default=None, description="ID of the image associated with the lesson")
    title: StrictStr = Field(default=..., description="Title of the lesson")
    payload: Optional[StrictStr] = Field(default='', description="Payload of the lesson, e.g. description or summary")
    is_active: StrictBool = Field(default=..., description="Whether the lesson is active or not")
    is_published: StrictBool = Field(default=..., description="Whether the lesson is published or not")
    mandatory: StrictBool = Field(default=..., description="Whether the lesson is mandatory to complete the module or not")
    order: Optional[StrictInt] = Field(default=None, description="Order of the lesson in the module, if not set, it will be added to the end")
    content_blocks: Optional[conlist(ContentBlockCreate)] = Field(default=None, description="List of content blocks to be created and included in lesson")
    attached_files: Optional[conlist(AttachedFileCreate)] = Field(default=None, description="List of attached files to be created and included in lesson")
    __properties = ["submodule_id", "thread_id", "lesson_type", "image_id", "title", "payload", "is_active", "is_published", "mandatory", "order", "content_blocks", "attached_files"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ModuleLessonCreate:
        """Create an instance of ModuleLessonCreate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in content_blocks (list)
        _items = []
        if self.content_blocks:
            for _item in self.content_blocks:
                if _item:
                    _items.append(_item.to_dict())
            _dict['content_blocks'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in attached_files (list)
        _items = []
        if self.attached_files:
            for _item in self.attached_files:
                if _item:
                    _items.append(_item.to_dict())
            _dict['attached_files'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ModuleLessonCreate:
        """Create an instance of ModuleLessonCreate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ModuleLessonCreate.parse_obj(obj)

        _obj = ModuleLessonCreate.parse_obj({
            "submodule_id": obj.get("submodule_id"),
            "thread_id": obj.get("thread_id"),
            "lesson_type": obj.get("lesson_type"),
            "image_id": obj.get("image_id"),
            "title": obj.get("title"),
            "payload": obj.get("payload") if obj.get("payload") is not None else '',
            "is_active": obj.get("is_active"),
            "is_published": obj.get("is_published"),
            "mandatory": obj.get("mandatory"),
            "order": obj.get("order"),
            "content_blocks": [ContentBlockCreate.from_dict(_item) for _item in obj.get("content_blocks")] if obj.get("content_blocks") is not None else None,
            "attached_files": [AttachedFileCreate.from_dict(_item) for _item in obj.get("attached_files")] if obj.get("attached_files") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictStr
from public_api_server_connector.models.category_permissions import CategoryPermissions

class ApiKeyUpdate(BaseModel):
    """
    ApiKeyUpdate
    """
    name: StrictStr = Field(...)
    permissions: Optional[Dict[str, CategoryPermissions]] = Field(default=None, description="Permissions for each category, where the key is the category name and the value is the permissions.")
    __properties = ["name", "permissions"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiKeyUpdate:
        """Create an instance of ApiKeyUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each value in permissions (dict)
        _field_dict = {}
        if self.permissions:
            for _key in self.permissions:
                if self.permissions[_key]:
                    _field_dict[_key] = self.permissions[_key].to_dict()
            _dict['permissions'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiKeyUpdate:
        """Create an instance of ApiKeyUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiKeyUpdate.parse_obj(obj)

        _obj = ApiKeyUpdate.parse_obj({
            "name": obj.get("name"),
            "permissions": {
                _k: CategoryPermissions.from_dict(_v) for _k, _v in obj["permissions"].items()
            }
            if obj.get("permissions") is not None
            else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CourseModuleViewTypeStrEnum(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    LIST = 'list'
    GRID = 'grid'

    @classmethod
    def from_json(cls, json_str: str) -> CourseModuleViewTypeStrEnum:
        """Create an instance of CourseModuleViewTypeStrEnum from a JSON string"""
        return CourseModuleViewTypeStrEnum(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from public_api_server_connector.models.ipn_transaction import IpnTransaction
from public_api_server_connector.models.marketplace_buyer import MarketplaceBuyer

class IpnOrderPayment(BaseModel):
    """
    IpnOrderPayment
    """
    marketplace_buyer: MarketplaceBuyer = Field(default=..., description="Marketplace buyer information, including email, name, phone number and address")
    course_ids: conlist(StrictInt) = Field(default=..., description="List of course ids that are being paid for and should be unlocked for the buyer")
    id: Optional[StrictStr] = Field(default=None, description="External id of the order, if provided it will be prefixed with portal id, e.g. {portal_id}-{order.id}, if not provided it will be generated by the server")
    transaction: Optional[IpnTransaction] = Field(default=None, description="Transaction information, including amount and external id")
    send_email: Optional[StrictBool] = Field(default=True, description="Whether to send an email notification to the buyer after the order is created")
    __properties = ["marketplace_buyer", "course_ids", "id", "transaction", "send_email"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IpnOrderPayment:
        """Create an instance of IpnOrderPayment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of marketplace_buyer
        if self.marketplace_buyer:
            _dict['marketplace_buyer'] = self.marketplace_buyer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction
        if self.transaction:
            _dict['transaction'] = self.transaction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IpnOrderPayment:
        """Create an instance of IpnOrderPayment from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IpnOrderPayment.parse_obj(obj)

        _obj = IpnOrderPayment.parse_obj({
            "marketplace_buyer": MarketplaceBuyer.from_dict(obj.get("marketplace_buyer")) if obj.get("marketplace_buyer") is not None else None,
            "course_ids": obj.get("course_ids"),
            "id": obj.get("id"),
            "transaction": IpnTransaction.from_dict(obj.get("transaction")) if obj.get("transaction") is not None else None,
            "send_email": obj.get("send_email") if obj.get("send_email") is not None else True
        })
        return _obj


